@@ -4,13 +4,12 @@ use 5.010001;
 use strict;
 use warnings;
 
-use My::Inline;
 use SPVM 'Examples::Prime';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-11-23'; # DATE
 our $DIST = 'Bencher-Scenarios-SPVM'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark SPVM (check if number is prime)',
@@ -19,13 +18,14 @@ our $scenario = {
         'SPVM::Examples' => {}, # to pull dependency
     },
     participants => [
-        { name => 'Inline::C', code => sub { My::Inline::is_prime(1_000_003) } },
+        { name => 'Inline::C', code => sub { My::Prime::Inline::is_prime(1_000_003) } },
         { name => 'Perl',      code => sub { My::Prime->is_prime(1_000_003) } },
         { name => 'SPVM',      code => sub { SPVM::Examples::Prime->is_prime(1_000_003) } },
     ],
 };
 
-package My::Prime;
+package
+    My::Prime;
 
 sub is_prime {
     my $self = shift;
@@ -38,6 +38,20 @@ sub is_prime {
     1;
 }
 
+package
+    My::Prime::Inline;
+
+use Inline C => <<'_';
+int is_prime(int num) {
+  int limit = num - 1; /* a naive algorithm */
+  int i;
+  for (i=2; i<=limit; i++) {
+    if (num % i == 0) return 1;
+  }
+  return 0;
+}
+_
+
 1;
 # ABSTRACT: Benchmark SPVM (check if number is prime)
 
@@ -53,7 +67,7 @@ Bencher::Scenario::SPVM::Prime - Benchmark SPVM (check if number is prime)
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::SPVM::Prime (from Perl distribution Bencher-Scenarios-SPVM), released on 2022-11-23.
+This document describes version 0.005 of Bencher::Scenario::SPVM::Prime (from Perl distribution Bencher-Scenarios-SPVM), released on 2022-11-23.
 
 =head1 SYNOPSIS
 
@@ -100,21 +114,21 @@ Run on: perl: I<< v5.34.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz
 Benchmark with default options (C<< bencher -m SPVM::Prime >>):
 
  #table1#
- +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | participant | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
- +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Perl        |        21 |        47 |                 0.00% |              1589.46% | 5.4e-05 |      20 |
- | SPVM        |        40 |        25 |                91.17% |               783.76% | 7.2e-05 |      21 |
- | Inline::C   |       400 |         3 |              1589.46% |                 0.00% | 3.2e-05 |      20 |
- +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
+ | participant | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
+ | Perl        |        20 |     50    |                 0.00% |              1815.29% |   0.00065 |      20 |
+ | SPVM        |        39 |     25    |                94.91% |               882.65% |   0.00011 |      21 |
+ | Inline::C   |       386 |      2.59 |              1815.29% |                 0.00% | 4.1e-07   |      22 |
+ +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
 
 Formatted as L<Benchmark.pm|Benchmark> result:
 
               Rate   Perl  SPVM  Inline::C 
-  Perl        21/s     --  -46%       -93% 
-  SPVM        40/s    87%    --       -88% 
-  Inline::C  400/s  1466%  733%         -- 
+  Perl        20/s     --  -50%       -94% 
+  SPVM        39/s   100%    --       -89% 
+  Inline::C  386/s  1830%  865%         -- 
  
  Legends:
    Inline::C: participant=Inline::C
